==> qtjambi-network-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiNetwork/QNetworkProxyFactory_shell.cpp <==
#include "QNetworkProxyFactory_shell.h"
#include <QtJambi/Cast>

void deleter_QNetworkProxyFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNetworkProxyFactory")
    QNetworkProxyFactory *_ptr = reinterpret_cast<QNetworkProxyFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QNetworkProxyFactory_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QNetworkProxyFactory_shell) ); }

jmethodID QNetworkProxyFactory_oshell::__shell_javaMethod(int pos) const { return QNetworkProxyFactory_shell::__shell()->javaMethod(typeid(QNetworkProxyFactory), pos); }

// emitting (writeShellDestructor)
QNetworkProxyFactory_shell::~QNetworkProxyFactory_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QNetworkProxyFactory::~QNetworkProxyFactory()", this)
    QNetworkProxyFactory_shell::__shell()->destructed(typeid(QNetworkProxyFactory));
}

// emitting (writeShellConstructor)
QNetworkProxyFactory_shell::QNetworkProxyFactory_shell()
    : QNetworkProxyFactory()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QNetworkProxyFactory::QNetworkProxyFactory_shell()", this)
    QNetworkProxyFactory_shell::__shell()->constructed(typeid(QNetworkProxyFactory));
}

void QNetworkProxyFactory_oshell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QNetworkProxyFactory_oshell*>(ptr)->QNetworkProxyFactory_oshell::__shell()->tryDeleteShell(typeid(QNetworkProxyFactory));
}

// emitting Virtual overrides (virtualFunctions)
QList<QNetworkProxy> QNetworkProxyFactory_oshell::queryProxy(const QNetworkProxyQuery& query0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        if (JniEnvironmentScopeExceptionHandler __jni_env{QNetworkProxyFactory_shell::__shell(), 300}) {
            QList<QNetworkProxy>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = __jni_env.getJavaObjectLocalRef()){
                    jobject __java_query0 = qtjambi_cast<jobject>(__jni_env, query0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_query0);
                    __jni_env.checkException( QTJAMBI_STACKTRACEINFO_NOENV );
                    __qt_return_value = qtjambi_cast<QList<QNetworkProxy> >(__jni_env, __jni_env.scope(), __java_return_value);
                } else {
                    QNetworkProxyFactory_shell::__shell()->warnForMethod("QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __jni_env.handleException(exn, "QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QNetworkProxy>();
        }
    }else{
        return QList<QNetworkProxy>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QNetworkProxyFactory_access::__qt_queryProxy_cref_QNetworkProxyQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID query0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QNetworkProxyFactory::queryProxy(const QNetworkProxyQuery & query)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QNetworkProxyFactory::queryProxy(const QNetworkProxyQuery & query).";
    } else {
        QList<QNetworkProxy> __qt_return_value = queryProxy(__qt_query0);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QNetworkProxyFactory()
void __qt_construct_QNetworkProxyFactory(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNetworkProxyFactory()")
    Q_UNUSED(__java_arguments)
    QNetworkProxyFactory *__qt_this = new(__qtjambi_ptr) QNetworkProxyFactory_oshell();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QNetworkProxyFactory::QNetworkProxyFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_initialize_1native__Lio_qt_network_QNetworkProxyFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::QNetworkProxyFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNetworkProxyFactory, sizeof(QNetworkProxyFactory_shell), typeid(QNetworkProxyFactory), 0, true, &deleter_QNetworkProxyFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QNetworkProxyFactory_shell
void __qt_destruct_QNetworkProxyFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNetworkProxyFactory")
    reinterpret_cast<QNetworkProxyFactory_shell*>(ptr)->~QNetworkProxyFactory_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_00024ConcreteWrapper_queryProxy_1native_1cref_1QNetworkProxyQuery__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID query0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QNetworkProxyFactory *__qt_this = QtJambiAPI::objectFromNativeId<QNetworkProxyFactory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)", __this_nativeId)
        __java_return_value = static_cast<QNetworkProxyFactory_access*>(__qt_this)->__qt_queryProxy_cref_QNetworkProxyQuery(__jni_env, __this_nativeId, query0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::proxyForQuery(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_proxyForQuery_1native_1cref_1QNetworkProxyQuery__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID query0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::proxyForQuery(QNetworkProxyQuery)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
        QList<QNetworkProxy> __qt_return_value = QNetworkProxyFactory::proxyForQuery(__qt_query0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::setApplicationProxyFactory(QNetworkProxyFactory*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_setApplicationProxyFactory_1native_1QNetworkProxyFactory_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID factory0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::setApplicationProxyFactory(QNetworkProxyFactory*)")
    QTJAMBI_TRY {
        QNetworkProxyFactory* __qt_factory0 = QtJambiAPI::objectFromNativeId<QNetworkProxyFactory>(factory0);
        QtJambiAPI::setCppOwnership(__jni_env, factory0);
        QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, factory0);
        QNetworkProxyFactory::setApplicationProxyFactory(__qt_factory0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNetworkProxyFactory::setUseSystemConfiguration(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_setUseSystemConfiguration__Z)
(JNIEnv *__jni_env,
 jclass,
 jboolean enable0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::setUseSystemConfiguration(bool)")
    QTJAMBI_TRY {
        QNetworkProxyFactory::setUseSystemConfiguration(static_cast<bool>(enable0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNetworkProxyFactory::systemProxyForQuery(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_systemProxyForQuery_1native_1cref_1QNetworkProxyQuery__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID query0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::systemProxyForQuery(QNetworkProxyQuery)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
        QList<QNetworkProxy> __qt_return_value = QNetworkProxyFactory::systemProxyForQuery(__qt_query0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::usesSystemConfiguration()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_usesSystemConfiguration__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::usesSystemConfiguration()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QNetworkProxyFactory::usesSystemConfiguration();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNetworkProxyFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QNetworkProxyFactory>("QNetworkProxyFactory", "io/qt/network/QNetworkProxyFactory");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "queryProxy", "(Lio/qt/network/QNetworkProxyQuery;)Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, 0, &__qt_destruct_QNetworkProxyFactory, {
        ConstructorInfo(&__qt_construct_QNetworkProxyFactory, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNetworkProxyFactory);
    registerSizeOfShell(typeId, sizeof(QNetworkProxyFactory_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-network-debuginfo-windows-x64-6.6.1.jar: sources/QtJambiNetwork/QNetworkProxyFactory_shell.cpp <==
#include "QNetworkProxyFactory_shell.h"
#include <QtJambi/Cast>

void deleter_QNetworkProxyFactory(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNetworkProxyFactory")
    QNetworkProxyFactory *_ptr = reinterpret_cast<QNetworkProxyFactory *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QNetworkProxyFactory_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QNetworkProxyFactory_shell) ); }

jmethodID QNetworkProxyFactory_shell::__shell_javaMethod(int pos) const { return QNetworkProxyFactory_shell::__shell()->javaMethod(typeid(QNetworkProxyFactory), pos); }

// emitting (writeShellConstructor)
QNetworkProxyFactory_shell::QNetworkProxyFactory_shell()
    : QNetworkProxyFactory()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QNetworkProxyFactory::QNetworkProxyFactory_shell()", QNetworkProxyFactory_shell::__shell())
    QNetworkProxyFactory_shell::__shell()->constructed(typeid(QNetworkProxyFactory));
}

// emitting (writeShellDestructor)
QNetworkProxyFactory_shell::~QNetworkProxyFactory_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QNetworkProxyFactory::~QNetworkProxyFactory()", QNetworkProxyFactory_shell::__shell())
    QNetworkProxyFactory_shell::__shell()->destructed(typeid(QNetworkProxyFactory));
}

void QNetworkProxyFactory_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QNetworkProxyFactory_shell*>(ptr)->QNetworkProxyFactory_shell::__shell()->tryDeleteShell(typeid(QNetworkProxyFactory));
}

// emitting Virtual overrides (virtualFunctions)
QList<QNetworkProxy> QNetworkProxyFactory_shell::queryProxy(const QNetworkProxyQuery& query0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)", QNetworkProxyFactory_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QList<QNetworkProxy>  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QNetworkProxyFactory_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    QtJambiScope __qtjambi_scope(QNetworkProxyFactory_shell::__shell());
                    jobject __java_query0 = qtjambi_cast<jobject>(__jni_env, query0);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_query0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QList<QNetworkProxy> >(__jni_env, __qtjambi_scope, __java_return_value);
                } else {
                    QNetworkProxyFactory_shell::__shell()->warnForMethod("QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QList<QNetworkProxy>();
        }
    }else{
        return QList<QNetworkProxy>();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QNetworkProxyFactory_access::__qt_queryProxy_cref_QNetworkProxyQuery(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID query0)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QNetworkProxyFactory::queryProxy(const QNetworkProxyQuery & query)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QNetworkProxyFactory::queryProxy(const QNetworkProxyQuery & query).";
    } else {
        QList<QNetworkProxy> __qt_return_value = queryProxy(__qt_query0);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QNetworkProxyFactory()
void __qt_construct_QNetworkProxyFactory_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNetworkProxyFactory()")
    Q_UNUSED(__java_arguments)
    QNetworkProxyFactory *__qt_this = new(__qtjambi_ptr) QNetworkProxyFactory_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QNetworkProxyFactory_shell
void __qt_destruct_QNetworkProxyFactory(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNetworkProxyFactory")
    reinterpret_cast<QNetworkProxyFactory_shell*>(ptr)->~QNetworkProxyFactory_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNetworkProxyFactory::QNetworkProxyFactory()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_initialize_1native__Lio_qt_network_QNetworkProxyFactory_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::QNetworkProxyFactory()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNetworkProxyFactory_0, sizeof(QNetworkProxyFactory_shell), typeid(QNetworkProxyFactory), true, &deleter_QNetworkProxyFactory, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_00024ConcreteWrapper_queryProxy_1native_1cref_1QNetworkProxyQuery__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID query0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QNetworkProxyFactory *__qt_this = QtJambiAPI::objectFromNativeId<QNetworkProxyFactory>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNetworkProxyFactory::queryProxy(QNetworkProxyQuery)", __qt_this)
        __java_return_value = static_cast<QNetworkProxyFactory_access*>(__qt_this)->__qt_queryProxy_cref_QNetworkProxyQuery(__jni_env, __this_nativeId, query0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::proxyForQuery(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_proxyForQuery_1native_1cref_1QNetworkProxyQuery__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID query0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::proxyForQuery(QNetworkProxyQuery)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
        QList<QNetworkProxy> __qt_return_value = QNetworkProxyFactory::proxyForQuery(__qt_query0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::setApplicationProxyFactory(QNetworkProxyFactory*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_setApplicationProxyFactory_1native_1QNetworkProxyFactory_1ptr__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID factory0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::setApplicationProxyFactory(QNetworkProxyFactory*)")
    QTJAMBI_TRY {
        QNetworkProxyFactory* __qt_factory0 = QtJambiAPI::objectFromNativeId<QNetworkProxyFactory>(factory0);
        QtJambiAPI::setCppOwnership(__jni_env, factory0);
        QNetworkProxyFactory::setApplicationProxyFactory(__qt_factory0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNetworkProxyFactory::setUseSystemConfiguration(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_setUseSystemConfiguration__Z)
(JNIEnv *__jni_env,
 jclass,
 jboolean enable0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::setUseSystemConfiguration(bool)")
    QTJAMBI_TRY {
        QNetworkProxyFactory::setUseSystemConfiguration(static_cast<bool>(enable0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNetworkProxyFactory::systemProxyForQuery(QNetworkProxyQuery)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_systemProxyForQuery_1native_1cref_1QNetworkProxyQuery__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID query0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::systemProxyForQuery(QNetworkProxyQuery)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNetworkProxyQuery& __qt_query0 = QtJambiAPI::valueReferenceFromNativeId<QNetworkProxyQuery>(query0);
        QList<QNetworkProxy> __qt_return_value = QNetworkProxyFactory::systemProxyForQuery(__qt_query0);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNetworkProxyFactory::usesSystemConfiguration()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QNetworkProxyFactory_usesSystemConfiguration__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNetworkProxyFactory::usesSystemConfiguration()")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        __java_return_value = QNetworkProxyFactory::usesSystemConfiguration();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNetworkProxyFactory(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QNetworkProxyFactory>("QNetworkProxyFactory", "io/qt/network/QNetworkProxyFactory");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "queryProxy", "(Lio/qt/network/QNetworkProxyQuery;)Ljava/util/List;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QNetworkProxyFactory, {
        ConstructorInfo(&__qt_construct_QNetworkProxyFactory_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNetworkProxyFactory);
    registerSizeOfShell(typeId, sizeof(QNetworkProxyFactory_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
